==> html-compiler-loader-1.2.4.tgz: package/lib/process-bem.js <==
module.exports = function (node) {
  let parentBlock
  if (node.attrs && node.attrs.parentBlock) {
    parentBlock = node.attrs.parentBlock
    delete node.attrs.parentBlock
  }
  if (node.attrs && node.attrs.elem && parentBlock) {
    let elem = parentBlock + '__' + node.attrs.elem
    delete node.attrs.elem
    if (node.attrs.mods && !node.attrs.block) {
      const mods = node.attrs.mods
        .replace(/\s*/g, '')
        .split(',')
      delete node.attrs.mods

      let classes = ''
      mods.forEach((mod) => {
        classes += ' ' + elem + '--' + mod
      })
      elem += classes
    }
    if (node.attrs.class) {
      node.attrs.class += ' ' + elem
    } else {
      node.attrs.class = elem
    }
  }
  if (node.attrs && node.attrs.block) {
    parentBlock = node.attrs.block
    delete node.attrs.block
    let block = parentBlock
    if (node.attrs.mods) {
      const mods = node.attrs.mods
        .replace(/\s*/g, '')
        .split(',')
      delete node.attrs.mods
      mods.forEach((mod) => {
        block += ' ' + parentBlock + '--' + mod
      })
    }
    if (node.attrs.class) {
      node.attrs.class += ' ' + block
    } else {
      node.attrs.class = block
    }
  }
  if (parentBlock) {
    if (node.content && Array.isArray(node.content)) {
      node.content.forEach((children) => {
        if (typeof children !== 'object') {
          return
        }
        children.attrs = children.attrs || {}
        children.attrs.parentBlock = parentBlock
      })
    }
  }
}

==> html-compiler-loader-1.4.0.tgz: package/lib/process-bem.js <==
module.exports = function (node) {
  let parentBlock
  if (node.attrs && node.attrs.parentBlock) {
    parentBlock = node.attrs.parentBlock
    delete node.attrs.parentBlock
  }
  if (node.attrs && node.attrs.elem && parentBlock) {
    const elems = node.attrs.elem.split(' ')
    delete node.attrs.elem
    let elem = parentBlock + '__' + elems[0]
    elems.splice(0, 1)
    if (node.attrs.mods && !node.attrs.block) {
      const mods = node.attrs.mods.split(' ')
      delete node.attrs.mods

      let classes = ''
      mods.forEach((mod) => {
        classes += ' ' + elem + '--' + mod
      })
      elem += classes
    }
    elems.forEach((anotherElem) => {
      elem += ' ' + parentBlock + '__' + anotherElem
    })

    if (node.attrs.class) {
      node.attrs.class += ' ' + elem
    } else {
      node.attrs.class = elem
    }
  }
  if (node.attrs && node.attrs.block) {
    parentBlock = node.attrs.block
    delete node.attrs.block
    let block = parentBlock
    if (node.attrs.mods) {
      const mods = node.attrs.mods.split(' ')
      delete node.attrs.mods
      mods.forEach((mod) => {
        block += ' ' + parentBlock + '--' + mod
      })
    }
    if (node.attrs.class) {
      node.attrs.class += ' ' + block
    } else {
      node.attrs.class = block
    }
  }
  if (parentBlock) {
    if (node.content && Array.isArray(node.content)) {
      node.content.forEach((children) => {
        if (typeof children !== 'object') {
          return
        }
        children.attrs = children.attrs || {}
        children.attrs.parentBlock = parentBlock
      })
    }
  }
}
